<?php 
/**
* Doublef Galleries class
*
* Doublef Galleries - WordPress theme plugin | This plugin creates "doublef-gallery" Custom Post Type, "doublef-galleries" Custom Taxonomy and throws in "Featured Gallery" SiteOrigin widget.
*
*/

class Doublef_Galleries {

	private static $instance;
	private $settings;
	
	// settings
	public static $cpt_slug = 'doublef-gallery';  // custom post type name
	public static $ct_slug  = 'doublef-galleries'; // custom taxonomy
	
	public static function get_instance() {
		if( !self::$instance ) {
			self::$instance = new self();
			self::$instance->init();
		}
		return self::$instance;
	}
	
	public function init() {
		
		// CMB2
		if( file_exists( DOUBLEF_GALLERIES_DIR . 'includes/CMB2/init.php' ) ) require_once DOUBLEF_GALLERIES_DIR . 'includes/CMB2/init.php';
		// register plugin options, make it available thru Kirki
		if( class_exists( 'Kirki' ) ) require_once DOUBLEF_GALLERIES_DIR . 'includes/doublef-galleries-customizer-options.php'; 
		
		// SiteOrigin widget
		if( class_exists( 'SiteOrigin_Panels_Settings' ) ) {
			add_filter( 'siteorigin_widgets_widget_folders', array( $this, 'doublef_galleries_siteorigin_widgets' ) );
			add_filter( 'siteorigin_widgets_active_widgets', array( $this, 'doublef_galleries_so_widgets_activate' ) );
		}
		
		// actions
		add_action( 'init', array( $this, 'doublef_galleries_cpt' ), 0 );
		add_action( 'manage_' . self::$cpt_slug . '_posts_custom_column', array( $this, 'doublef_galleries_manage_gallery_columns' ), 10, 2 );
		add_action( 'pre_get_posts', array( $this, 'doublef_galleries_filter_galleries_query' ) );
		add_action( 'save_post_' . self::$cpt_slug, array( $this, 'doublef_galleries_set_default_obj_terms' ) );
		
		// filters
		add_filter( 'manage_edit-' . self::$cpt_slug . '_columns', array( $this, 'doublef_galleries_edit_gallery_columns' ) );
		add_filter( 'single_template', array( $this, 'doublef_galleries_get_cpt_template' ), 11 );
		add_filter( 'archive_template', array( $this, 'doublef_galleries_get_cpt_archive' ), 11 );
		
		// scripts
		add_action( 'wp_enqueue_scripts', array( $this, 'doublef_galleries_enqueue_scripts' ) );
		
		// metaboxes, CMB2
		if( file_exists( DOUBLEF_GALLERIES_DIR . 'includes/CMB2/init.php' ) ) add_action( 'cmb2_admin_init', array( $this, 'doublef_galleries_create_required_metaboxes' ) );
		
		// plugin hooks
		register_activation_hook( __FILE__, array( $this, 'doublef_galleries_register_activation_hook' ) );
		register_deactivation_hook( __FILE__, array( $this, 'doublef_galleries_register_deactivation_hook' ) );
		
	}
	
	/** 
	* Plugin activation/deactivation hooks
	*/ 
	public function doublef_galleries_register_activation_hook() {
		
		$this->doublef_galleries_cpt();
		
	}
	public function doublef_galleries_register_deactivation_hook() {
		
		flush_rewrite_rules();
		
	}
	
	/**
	* Create required Metaboxes
	*/ 
public function doublef_galleries_create_required_metaboxes() {
		
		$doublef_gallery_mb_opts = new_cmb2_box( array(
			'id'            => DOUBLEF_GALLERIES_PREFIX . 'options',
			'title'         => esc_html__( 'Gallery post options', 'doublef-galleries' ),
			'object_types'  => array( self::$cpt_slug ), 
			// 'show_on_cb' => 'yourprefix_show_if_front_page', // function should return a bool value
			'context'    => 'normal',
			'priority'   => 'default',
			'show_names' => true, // Show field names on the left
			// 'cmb_styles' => false, // false to disable the CMB stylesheet
			// 'closed'     => true, // true to keep the metabox closed by default
			// 'classes'    => 'extra-class', // Extra cmb2-wrap classes
			// 'classes_cb' => 'yourprefix_add_some_classes', // Add classes through a callback.
		) );
		
		$doublef_gallery_mb_opts->add_field( array(
			'name' => esc_html__( 'Gallery Settings', 'doublef-galleries' ),
			'desc' => esc_html__( 'Upload photos or select from Media Library. Chose number of columns for your gallery.', 'doublef-galleries' ),
			'id'   => DOUBLEF_GALLERIES_PREFIX . 'gal_meta_title',
			'type' => 'title',
		) );
		
		$doublef_gallery_mb_opts->add_field( array(
			'name'             => esc_html__( 'Gallery Columns', 'doublef-galleries' ),
			'desc'             => esc_html__( 'Photos are displayed in grid. How many columns the grid should have?', 'doublef-galleries' ),
			'id'               => DOUBLEF_GALLERIES_PREFIX . 'gal_cols_num',
			'type'             => 'select',
			'show_option_none' => FALSE,
			'default'          => '4',
			'options'          => array(
				'6' => esc_attr__( 'Two columns', 'doublef-galleries' ),
				'4' => esc_attr__( 'Three columns', 'doublef-galleries' ),
				'3' => esc_attr__( 'Four columns', 'doublef-galleries' ), 
			),
		) );
		
		$doublef_gallery_mb_opts->add_field( array(
			'name'             => esc_html__( 'Show photo caption?', 'doublef-galleries' ),
			'desc'             => esc_html__( 'Whether to show or hide photo caption', 'doublef-galleries' ),
			'id'               => DOUBLEF_GALLERIES_PREFIX . 'gal_show_photo_descr',
			'type'             => 'select',
			'show_option_none' => FALSE,
			'default'          => 'no',
			'options'          => array(
				'no' => esc_attr__( 'No', 'doublef-galleries' ),
				'yes' => esc_attr__( 'Yes', 'doublef-galleries' ), 
			),
		) );
		
		$doublef_gallery_mb_opts->add_field( array(
			'name' => esc_html__( 'Gallery Photos', 'doublef-galleries' ),
			'desc' => esc_html__( 'Upload as many photos as you like.', 'doublef-galleries' ),
			'id'   => DOUBLEF_GALLERIES_PREFIX . 'gal_photos',
			'type' => 'file_list',
			'preview_size' => array( 180, 90 ), // Default: array( 50, 50 )
			'query_args' => array( 'type' => 'image' ), // Only images attachment
			// Optional, override default text strings
			'text' => array(
				'add_upload_files_text' => esc_html__( 'Add Photo', 'doublef-galleries' ),
				'remove_image_text' => esc_html__( 'Remove Photo', 'doublef-galleries' ),
				'file_text' => esc_html__( 'Photo:', 'doublef-galleries' ),
				'file_download_text' => esc_html__( 'Download', 'doublef-galleries' ),
				'remove_text' => esc_html__( 'Remove Photo', 'doublef-galleries' ),
			),
		) );
		
	}
	
	/**
	* SiteOrigin widgets location
	*/ 
	public function doublef_galleries_siteorigin_widgets( $folders ) {
		
		$folders[] = DOUBLEF_GALLERIES_DIR . 'siteorigin-widgets/';
		
		return $folders;
		
	}
	
	/**
	* SiteOrigin widgets activate / deactivate at theme activation
	*/ 
	public function doublef_galleries_so_widgets_activate( $active ) {
		
		$active[ 'doublef-featured-gallery' ] = TRUE;
		
		return $active;
		
	}
	
	/**
	* Enqueue scripts and styles
	*/
	public function doublef_galleries_enqueue_scripts() {
		wp_enqueue_style(
			'doublef-galleries-styles',
			DOUBLEF_GALLERIES_URI . 'assets/css/style.css',
			array(),
			DOUBLEF_GALLERIES_VER
		); // Main CSS
	}

	/**
	* Register CT and CPT
	*/
	public function doublef_galleries_cpt() {
		
		// grab options from settings page !!!
		$ct_slug  = get_theme_mod( 'doublef-galleries-rewrite-ct-slug', '' );
		$cpt_slug = get_theme_mod( 'doublef-galleries-rewrite-cpt-slug', '' );
		
		$gallery_rewrite_ct_slug  = ( '' != $ct_slug ) ? esc_attr__( $ct_slug ): '';
		$gallery_rewrite_cpt_slug = ( '' != $cpt_slug ) ? esc_attr__( $cpt_slug ): '';
		
		// check for input
		$pattern = '/^[a-z]+([a-z0-9_]*)?[a-z0-9]+$/i';
		if( ! preg_match( $pattern, $gallery_rewrite_ct_slug ) ) $gallery_rewrite_ct_slug = self::$ct_slug;
		if( ! preg_match( $pattern, $gallery_rewrite_cpt_slug ) ) $gallery_rewrite_cpt_slug = self::$cpt_slug;
		
		$labels_gallery = array(
			'name'               => esc_attr__( 'Galleries', 'doublef-galleries' ),
			'singular_name'      => esc_attr__( 'Gallery', 'doublef-galleries' ),
			'add_new'            => esc_attr__( 'Add New', 'doublef-galleries' ),
			'add_new_item'       => esc_attr__( 'New Gallery Post', 'doublef-galleries'),
			'edit_item'          => esc_attr__( 'Edit', 'doublef-galleries' ),
			'new_item'           => esc_attr__( 'New Gallery Post', 'doublef-galleries' ),
			'all_items'          => esc_attr__( 'All Galleries', 'doublef-galleries' ),
			'view_item'          => esc_attr__( 'View', 'doublef-galleries'),
			'search_items'       => esc_attr__( 'Search', 'doublef-galleries' ),
			'not_found'          => esc_attr__( 'Nothing found', 'doublef-galleries' ),
			'not_found_in_trash' => esc_attr__( 'Nothing found in Trash', 'doublef-galleries' ), 
			'parent_item_colon'  => esc_attr__( 'Parent:', 'doublef-galleries' ),
			'menu_name'          => esc_attr__( 'Galleries', 'doublef-galleries' ),
		);
		$args_gallery = array(
			'labels'             => $labels_gallery,
			'menu_icon'			 => 'dashicons-format-gallery',
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true, 
			'show_in_menu'       => true, 
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $gallery_rewrite_cpt_slug ),
			'capability_type'    => 'post',
			'has_archive'        => true, 
			'hierarchical'       => true,
			'menu_position'      => 24,
			'supports'           => array( 'title', 'editor', 'thumbnail', 'comments' ),
		); 
		if( ! post_type_exists( self::$cpt_slug ) ) register_post_type( self::$cpt_slug, $args_gallery ); // register CPT
		
		$labels_galleries = array(
			'name'              => esc_attr__( 'Gallery Categories', 'doublef-galleries' ),
			'singular_name'     => esc_attr__( 'Gallery Category', 'doublef-galleries' ),
			'search_items'      => esc_attr__( 'Search', 'doublef-galleries' ),
			'all_items'         => esc_attr__( 'Gallery Categories', 'doublef-galleries' ),
			'parent_item'       => esc_attr__( 'Parent Category', 'doublef-galleries' ),
			'parent_item_colon' => esc_attr__( 'Parent Categories:', 'doublef-galleries' ),
			'edit_item'         => esc_attr__( 'Edit Category', 'doublef-galleries' ),
			'update_item'       => esc_attr__( 'Update Category', 'doublef-galleries' ),
			'add_new_item'      => esc_attr__( 'Add New Category', 'doublef-galleries' ),
			'new_item_name'     => esc_attr__( 'New Category Name', 'doublef-galleries' ),
			'menu_name'         => esc_attr__( 'Gallery Categories', 'doublef-galleries' ),
		);
		$args_galleries = array(
			'hierarchical'      => true,
			'labels'            => $labels_galleries,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => $gallery_rewrite_ct_slug ),
		);
		register_taxonomy( self::$ct_slug, array( self::$cpt_slug ), $args_galleries ); // register CT
		
		flush_rewrite_rules();
		
		//---------------------------------------------------------------------------
		// end
	}
	
	/**
	* CPT Admin view
	*/
	public function doublef_galleries_edit_gallery_columns( $columns ) {
		$columns = array(
			'cb' => '<input type="checkbox" />',
			'featured_image' => esc_attr__( 'Featured Image', 'doublef-galleries' ),
			'title' => esc_attr__( 'Gallery Title', 'doublef-galleries' ),
			'taxonomy-' . self::$ct_slug => esc_attr__( 'Gallery Categories', 'doublef-galleries' ),
			'gall_ID' => esc_attr__( 'Gallery ID', 'doublef-galleries' ),
			'date' => esc_attr__( 'Date posted', 'doublef-galleries' ), 
		);
		return $columns;
	}
	

	// fill up with data
	public function doublef_galleries_manage_gallery_columns( $column, $post_id ) {

		switch( $column ) {
	
			case 'featured_image' :
	
				if( has_post_thumbnail( $post_id ) ) echo get_the_post_thumbnail( $post_id, 'thumbnail' );
				else echo esc_attr_x( '-----', 'non-existing table value', 'doublef-galleries' );
				break;
				
			case 'gall_ID' :
	
				echo $post_id;
				break;
	
			default : break;
			
		}
		
	}
	
	
	/** 
	* DEFAULT TERMS FOR Custom Taxonomies
	* WordPress' posts have default category named 'Uncategorized', Custom Post Types should follow the logic
	*/
	public function doublef_galleries_set_default_obj_terms( $post_id ) {
		
		if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return( $post_id );
		
		if( isset( $_POST[ 'post_status' ] ) && 'publish' === $_POST[ 'post_status' ] ) {
			// set defaults
			$defaults = array( self::$ct_slug => array( 'All Galleries' ) );
			$taxonomies = get_object_taxonomies( self::$cpt_slug );
			
			foreach( (array)$taxonomies as $taxonomy ) {
				$terms = wp_get_post_terms( $post_id, $taxonomy );
				if( empty( $terms ) && array_key_exists( $taxonomy, $defaults ) ) {
					$info = wp_set_object_terms( $post_id, $defaults[ $taxonomy ], $taxonomy );
				}
			}
			
		}
		
	}

	
	/**
	 Enable posts filtering
	 *
	 */ 
	public function doublef_galleries_filter_galleries_query( $query ) {
		
		if( $query->is_main_query() && $query->is_tax( self::$ct_slug ) ) {
			
			$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
			$query->set( 'post_type', array( self::$cpt_slug ) );
			$query->set( 'paged', $paged );
			
		}
		
		return $query;
		
	}
	
	
	/**
	 Grab Gallery by title
	 *
	 */ 
	public static function doublef_galleries_get_gallery_by_title() {

		// return array
		$arr_ID_title = array();
		// query args
		$gbt_query_args = array(
			'post_type' => self::$cpt_slug, 
			'post_status' => 'publish', 
			'posts_per_page' => -1,  
		);
		
		$posts = get_posts( $gbt_query_args );
		
		if( $posts ) {
			
			foreach( $posts as $post ) {
				
				$arr_ID_title[ $post->ID ] = esc_attr( $post->post_title );
				
			}
			
			wp_reset_postdata();
			
		}
		
		return $arr_ID_title;
		
	}
	
	
	/** 
	* Add Template Locations 
	*/ 
	public function doublef_galleries_get_cpt_template( $single_template ) {
		global $post;
		// we must allow parent or child theme to override plugin templates in case of customization. Entire "templates" folder should be copied from a plugin to theme's or child theme's root folder!
		if( $post->post_type == self::$cpt_slug ) {
			if( $overridden_template = locate_template( 'templates/single-' . self::$cpt_slug . '.php' ) ) $single_template = $overridden_template;
			else $single_template = DOUBLEF_GALLERIES_DIR . 'includes/templates/single-' . self::$cpt_slug . '.php';
		}
		return $single_template;
	}

	public function doublef_galleries_get_cpt_archive( $archive_template ) {
		// we must allow parent or child theme to override plugin templates in case of customization. Entire "templates" folder should be copied from a plugin to theme's or child theme's root folder!
		if( is_tax( self::$ct_slug ) || is_post_type_archive( self::$cpt_slug ) ) {
			if( '' != locate_template( 'templates/archive-' . self::$cpt_slug . '.php' ) ) $archive_template = locate_template( 'templates/archive-' . self::$cpt_slug . '.php' );
			else $archive_template = DOUBLEF_GALLERIES_DIR . 'includes/templates/archive-' . self::$cpt_slug . '.php';		
		}
		return $archive_template;
	}
	
	public static function doublef_galleries_get_cpt_archive_part() {
		$chosen_template = ( '' != get_theme_mod( 'doublef-galleries-cat-layout', 'layout_1' ) ) ? esc_attr__( get_theme_mod( 'doublef-galleries-cat-layout', 'layout_1' ) ) : 'layout_1';
		$archive_template_part = '';
		// we must allow parent or child theme to override plugin templates in case of customization. Entire "templates" folder should be copied from a plugin to theme's or child theme's root folder!
		if( is_tax( self::$ct_slug ) || is_post_type_archive( self::$cpt_slug ) ) {
			if( '' != locate_template( 'templates/archive-' . self::$cpt_slug . '-' . $chosen_template . '.php' ) ) $archive_template_part = locate_template( 'templates/archive-' . self::$cpt_slug . '-' . $chosen_template . '.php' );
			else $archive_template_part = DOUBLEF_GALLERIES_DIR . 'includes/templates/archive-' . self::$cpt_slug . '-' . $chosen_template . '.php';		
		}
		return $archive_template_part;
	}
	
	public static function doublef_gallery_posts_archive_part( $chosen_template = '' ) {
		if( '' == $chosen_template ) $chosen_template = 'layout_1';
		$archive_template_part = '';
		// we must allow parent or child theme to override plugin templates in case of customization. Entire "templates" folder should be copied from a plugin to theme's or child theme's root folder!
		if( '' != locate_template( 'templates/archive-' . self::$cpt_slug . '-' . $chosen_template . '.php' ) ) $archive_template_part = locate_template( 'templates/archive-' . self::$cpt_slug . '-' . $chosen_template . '.php' );
		else $archive_template_part = DOUBLEF_GALLERIES_DIR . 'includes/templates/archive-' . self::$cpt_slug . '-' . $chosen_template . '.php';		

		return $archive_template_part;
	}

}