<?php
/**
 * WPress Kirki Customizer
 *
 * @package Doublef Galleries Plugin 
 */

// wp_kses_post sanitize textarea
if( ! function_exists( 'doublef_galleries_sanitize_textarea' ) ) : 
	function doublef_galleries_sanitize_textarea( $text ) { 
		return wp_kses_post( $text );
	}
endif;

// Basic config 
Kirki::add_config( 'doublef_galleries', array(
    'capability'    => 'edit_theme_options',
    'option_type'   => 'theme_mod',
) );
// Plugin's panel ----------------------------------------------------------------------------------------------- //
Kirki::add_panel( 'doublef_galleries_panel', array(
    'title'    => esc_attr__( 'Doublef Galleries Plugin', 'doublef-galleries' ),
    'priority' => 12000,
) );

/* general stuff */
Kirki::add_section( 'doublef_galleries_general_settings', array(
    'title'          => esc_attr__( 'General Settings', 'doublef-galleries' ),
    'panel'          => 'doublef_galleries_panel', 
    'priority'       => 10,
    'capability'     => 'edit_theme_options',
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'custom',
	'settings'    => 'doublef-galleries-rewrite-html',
	'label'       => esc_attr__( 'Rewrite Rules', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_general_settings',
	'default'     => wp_kses_post( __( 'Default Custom Taxonomy slug is "doublef-galleries". It will become a part of the permalink (URL). You can rewrite it here with whatever keyword you prefer.<br />BEWARE: Only alphanumeric characters are allowed while spaces must be replaced with underscores! No dashes or quotes allowed!<br />For instance: my_new_ct_slug is OK. mynewctslug29 is also OK.<br />Likewise, default custom post type is "doublef-gallery" and you can change it to whatever keyword you prefer. Identical formatting rules apply here too!', 'doublef-galleries' ) ),
	'priority'    => 30,
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'     => 'text',
	'settings' => 'doublef-galleries-rewrite-ct-slug',
	'label'    => esc_attr__( 'Rewrite Custom Taxonomy slug', 'doublef-galleries' ),
	'section'  => 'doublef_galleries_general_settings', 
	'priority' => 40,
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'     => 'text',
	'settings' => 'doublef-galleries-rewrite-cpt-slug',
	'label'    => esc_attr__( 'Rewrite Custom Post Type slug', 'doublef-galleries' ),
	'section'  => 'doublef_galleries_general_settings', 
	'priority' => 50,
) );

/* single */
Kirki::add_section( 'doublef_galleries_single', array(
    'title'          => esc_attr__( 'Single Post', 'doublef-galleries' ),
    'panel'          => 'doublef_galleries_panel', 
    'priority'       => 20,
    'capability'     => 'edit_theme_options',
) );
	
Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'select',
	'settings'    => 'doublef-galleries-sidebar',
	'label'       => esc_attr__( 'Single Gallery post - use sidebar?', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_single',
	'default'     => 'no',
	'priority'    => 10,
	'choices'     => array(
		'yes' => esc_attr__( 'Yes', 'doublef-galleries' ), 
		'no' => esc_attr__( 'No', 'doublef-galleries' ),
	),
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'select',
	'settings'    => 'doublef-galleries-disable-comments',
	'label'       => esc_attr__( 'Disable comments?', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_single',
	'default'     => 'no',
	'priority'    => 20,
	'choices'     => array(
		'yes' => esc_attr__( 'Yes', 'doublef-galleries' ), 
		'no' => esc_attr__( 'No', 'doublef-galleries' ),
	),
) );

Kirki::add_field( 'doublef_galleries', array(
    'type'        => 'slider',
    'settings'    => 'doublef-galleries-single-title-size',
    'label'       => esc_attr__( 'Title font size', 'doublef-galleries' ),
    'section'     => 'doublef_galleries_single',
    'default'     => 2.2,
    'priority'    => 22,
    'choices'  => array(
        'min'  => 0.5,
        'max'  => 10,
        'step' => 0.1,
    ),
    'output' => array(
        array(
            'element'  => '.single .doublef-gallery .entry-title',
            'property' => 'font-size',
			'units' => 'em',
        ),
    ),
) );

Kirki::add_field( 'doublef_galleries', array(
    'type'        => 'slider',
    'settings'    => 'doublef-galleries-single-subtitle-size',
    'label'       => esc_attr__( 'Sub-title size', 'doublef-galleries' ),
	'description' => esc_attr__( 'Font size of "Number of Photos" info', 'doublef-galleries' ),
    'section'     => 'doublef_galleries_single',
    'default'     => 1.2,
    'priority'    => 30,
    'choices'  => array(
        'min'  => 0.5,
        'max'  => 10,
        'step' => 0.1,
    ),
    'output' => array(
        array(
            'element'  => '.single .doublef-gallery .doublef-gallery-photos-num',
            'property' => 'font-size',
			'units' => 'em',
        ),
    ),
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'select',
	'settings'    => 'doublef-galleries-show-prev-next-nav',
	'label'       => esc_attr__( 'Show Previous and Next Gallery links?', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_single',
	'default'     => 'no',
	'priority'    => 32,
	'choices'     => array(
		'yes' => esc_attr__( 'Yes', 'doublef-galleries' ), 
		'no' => esc_attr__( 'No', 'doublef-galleries' ),
	),
) );

/* archive */
Kirki::add_section( 'doublef_galleries_archive', array(
    'title'          => esc_attr__( 'Galleries Archive', 'doublef-galleries' ),
    'panel'          => 'doublef_galleries_panel', 
    'priority'       => 30,
    'capability'     => 'edit_theme_options',
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'select',
	'settings'    => 'doublef-galleries-cat-sidebar',
	'label'       => esc_attr__( 'Archive - use sidebar?', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_archive',
	'default'     => 'no',
	'priority'    => 10,
	'choices'     => array(
		'yes' => esc_attr__( 'Yes', 'doublef-galleries' ), 
		'no' => esc_attr__( 'No', 'doublef-galleries' ),
	),
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'select',
	'settings'    => 'doublef-galleries-cat-sidebar-side',
	'label'       => esc_attr__( 'Sidebar\'s side', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_archive',
	'default'     => 'right',
	'priority'    => 20,
	'choices'     => array(
		'right' => esc_attr__( 'Sidebar Right', 'doublef-galleries' ), 
		'left' => esc_attr__( 'Sidebar Left', 'doublef-galleries' ),
	),
    'active_callback'  => array(
        array(
            'setting'  => 'doublef-galleries-cat-sidebar',
            'value'    => 'yes',
            'operator' => '=',
        ),
    ),
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'radio-image',
	'settings'    => 'doublef-galleries-cat-layout',
	'label'       => esc_attr__( 'Select layout for Galleries archive', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_archive',
	'default'     => 'layout_1',
	'priority'    => 30,
	'choices'     => array(
		'layout_1' => esc_url( DOUBLEF_GALLERIES_URI . 'assets/images/doublef_galleries_layout_1.png' ), 
		'layout_2' => esc_url( DOUBLEF_GALLERIES_URI . 'assets/images/doublef_galleries_layout_2.png' ), 
		'layout_3' => esc_url( DOUBLEF_GALLERIES_URI . 'assets/images/doublef_galleries_layout_3.png' ), 
	),
) );

Kirki::add_field( 'doublef_galleries', array(
    'type'        => 'slider',
    'settings'    => 'doublef-galleries-cat-title-size',
    'label'       => esc_attr__( 'Title font size', 'doublef-galleries' ),
    'section'     => 'doublef_galleries_archive',
    'default'     => 1.4,
    'priority'    => 32,
    'choices'  => array(
        'min'  => 0.5,
        'max'  => 10,
        'step' => 0.1,
    ),
    'output' => array(
        array(
            'element'  => '.archive .doublef-gallery.layout_1 .entry-title, .archive .doublef-gallery.layout_2 .entry-title, .archive .doublef-gallery.layout_3 .entry-title',
            'property' => 'font-size',
			'units' => 'em',
        ),
    ),
) );

Kirki::add_field( 'doublef_galleries', array(
    'type'        => 'slider',
    'settings'    => 'doublef-galleries-cat-subtitle-size',
    'label'       => esc_attr__( 'Sub-title size', 'doublef-galleries' ),
	'description' => esc_attr__( 'Font size of "Number of Photos" info.', 'doublef-galleries' ),
    'section'     => 'doublef_galleries_archive',
    'default'     => 1,
    'priority'    => 34,
    'choices'  => array(
        'min'  => 0.5,
        'max'  => 10,
        'step' => 0.1,
    ),
    'output' => array(
        array(
            'element'  => '.archive .doublef-gallery.layout_1 .doublef-gallery-photos-num, .archive .doublef-gallery.layout_2 .doublef-gallery-photos-num, .archive .doublef-gallery.layout_3 .doublef-gallery-photos-num',
            'property' => 'font-size',
			'units' => 'em',
        ),
    ),
) );

	/* layout_1 options */
	Kirki::add_field( 'doublef_galleries', array(
		'type'        => 'select',
		'settings'    => 'doublef-galleries-cat-layout_1_ratio',
		'label'       => esc_attr__( 'Featured image to text ratio', 'doublef-galleries' ),
		'section'     => 'doublef_galleries_archive',
		'default'     => '1_2_1_2',
		'priority'    => 40,
		'choices'     => array(
			'1_4_3_4' => esc_attr__( '1/4 : 3/4', 'doublef-galleries' ),
			'1_3_2_3' => esc_attr__( '1/3 : 2/3', 'doublef-galleries' ),
			'1_2_1_2' => esc_attr__( '1/2 : 1/2', 'doublef-galleries' ),
			'2_3_1_3' => esc_attr__( '2/3 : 1/3', 'doublef-galleries' ),
			'3_4_1_4' => esc_attr__( '3/4 : 1/4', 'doublef-galleries' ),
		),
		'active_callback'  => array(
			array(
				'setting'  => 'doublef-galleries-cat-layout',
				'value'    => 'layout_1',
				'operator' => '=',
			),
		),
	) );
	
	/* layout_2 options */
	Kirki::add_field( 'doublef_galleries', array(
		'type'        => 'number',
		'settings'    => 'doublef-galleries-cat-layout_2_bleed',
		'label'       => esc_attr__( 'Text over image', 'doublef-galleries' ),
		'description' => esc_attr__( 'How many pixels to pull the text up? Beware, upward means over the image. It is negative margin!', 'doublef-galleries' ),
		'section'     => 'doublef_galleries_archive',
		'priority'    => 50,
		'default'     => -100,
		'choices'     => array(
			'min'  => -600,
			'max'  => 600,
			'step' => 1,
		),
		'active_callback'  => array(
			array(
				'setting'  => 'doublef-galleries-cat-layout',
				'value'    => 'layout_2',
				'operator' => '=',
			),
		),
		'output' => array(
			array(
				'element'  => '.doublef-gallery.layout_2 .post-thumbnail',
				'property' => 'margin-bottom',
				'units'    => 'px',
			),
		),
	) );
	
	Kirki::add_field( 'doublef_galleries', array(
		'type'        => 'number',
		'settings'    => 'doublef-galleries-cat-layout_2_trim',
		'label'       => esc_attr__( 'Content narrow down', 'doublef-galleries' ),
		'description' => esc_attr__( 'How many pixels to take from each side of the content?', 'doublef-galleries' ),
		'section'     => 'doublef_galleries_archive',
		'priority'    => 60,
		'default'     => 40,
		'choices'     => array(
			'min'  => 0,
			'max'  => 200,
			'step' => 1,
		),
		'active_callback'  => array(
			array(
				'setting'  => 'doublef-galleries-cat-layout',
				'value'    => 'layout_2',
				'operator' => '=',
			),
		),
		'output' => array(
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'margin-left',
				'units'    => 'px',
			),
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'margin-right',
				'units'    => 'px',
			),
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'margin-bottom',
				'units'    => 'px',
			),
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'padding-top',
				'units'    => 'px',
			),
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'padding-right',
				'units'    => 'px',
			),
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'padding-bottom',
				'units'    => 'px',
			),
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'padding-left',
				'units'    => 'px',
			),
		),
	) );
	
	Kirki::add_field( 'doublef_galleries', array(
		'type'        => 'color-alpha',
		'settings'    => 'doublef-galleries-cat-content-bg',
		'label'       => esc_attr__( 'Content background', 'doublef-galleries' ),
		'section'     => 'doublef_galleries_archive',
		'default'     => 'rgba(255, 255, 255, 1)',
		'priority'    => 64,
		'active_callback'  => array(
			array(
				'setting'  => 'doublef-galleries-cat-layout',
				'value'    => 'layout_2',
				'operator' => '=',
			),
		),
		'output'     => array(
			array(
				'element'  => '.doublef-gallery.layout_2 .doublef-galleries-content-wrap',
				'property' => 'background',
			),
		),
	) );
	
	Kirki::add_field( 'doublef_galleries', array(
		'type'        => 'toggle',
		'settings'    => 'doublef-galleries-cat-content-invert',
		'label'       => esc_attr__( 'Invert text color?', 'doublef-galleries' ),
		'section'     => 'doublef_galleries_archive',
		'default'     => '0',
		'priority'    => 66,
		'active_callback'  => array(
			array(
				'setting'  => 'doublef-galleries-cat-layout',
				'value'    => 'layout_2',
				'operator' => '=',
			),
		),
	) );
	
	/* layout_3 options */
	Kirki::add_field( 'doublef_galleries', array(
		'type'        => 'select',
		'settings'    => 'doublef-galleries-cat-layout_3_grid',
		'label'       => esc_attr__( 'Select number of columns', 'doublef-galleries' ),
		'section'     => 'doublef_galleries_archive',
		'default'     => '6',
		'priority'    => 70,
		'choices'     => array(
			'6' => esc_attr__( 'Two columns', 'doublef-galleries' ),
			'4' => esc_attr__( 'Three columns', 'doublef-galleries' ),
			'3' => esc_attr__( 'Four columns', 'doublef-galleries' ),
		),
		'active_callback'  => array(
			array(
				'setting'  => 'doublef-galleries-cat-layout',
				'value'    => 'layout_3',
				'operator' => '=',
			),
		),
	) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'multicheck',
	'settings'    => 'doublef-galleries-cat-item-display',
	'label'       => esc_attr__( 'What to show in loop?', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_archive',
	'multiple'    => 100, 
	'default'     => array( 'photos-num', 'featured-image', 'excerpt' ),
	'priority'    => 80,
	'choices'     => array(
		'photos-num' => esc_attr__( 'Number of Photos', 'doublef-galleries' ),
		'featured-image' => esc_attr__( 'Featured Image', 'doublef-galleries' ), 
		'excerpt' => esc_attr__( 'Excerpt', 'doublef-galleries' ), 
	),
) );

Kirki::add_field( 'doublef_galleries', array(
	'type'        => 'radio',
	'settings'    => 'doublef-galleries-cat-excerpt-mode',
	'label'       => esc_attr__( 'Show summary or full text of gallery post in loop?', 'doublef-galleries' ),
	'section'     => 'doublef_galleries_archive',
	'default'     => 'summary',
	'priority'    => 100,
	'choices'     => array(
		'summary' => esc_attr__( 'Short summary', 'doublef-galleries' ), 
		'fulltext' => esc_attr__( 'Full text', 'doublef-galleries' ),
	),
) );