<?php
/**
 * The template for displaying all single Event.
 *
 * @package Doublef
 */

get_header(); ?>

<?php
// plugin settings
$use_sidebar = ( '' != get_theme_mod( 'doublef-galleries-sidebar', 'no' ) ) ? esc_attr__( get_theme_mod( 'doublef-galleries-sidebar', 'no' ) ) : 'no';
$disable_comments = ( '' != get_theme_mod( 'doublef-galleries-disable-comments', 'no' ) ) ? esc_attr__( get_theme_mod( 'doublef-galleries-disable-comments', 'no' ) ) : 'no';
// determine class
$content_class  = ' grid__col grid__col--2-of-3 grid__col--m-1-of-1';
if( 'no' == $use_sidebar ) $content_class = ' grid__col grid__col--3-of-3';
// content position
$content_pos = get_theme_mod( 'doublef-galleries-content-pos', 'below' );
?>

<div id="primary" class="content-area<?php echo esc_attr( $content_class ); ?>">

    <main id="main" class="site-main" role="main">

    <?php while( have_posts() ) : the_post(); ?>
    
		<?php
        // photos num
        $photos_in_gallery = 0;
        // meta
        $gallery_repository = get_post_meta( get_the_ID(), DOUBLEF_GALLERIES_PREFIX . 'gal_photos', TRUE );
		$gallery_photo_ids = array();
        if( ! empty( $gallery_repository ) ) {
			
			$photos_in_gallery = count( $gallery_repository );
			
			foreach ( (array)$gallery_repository as $attachment_id => $attachment_url ) {
				$gallery_photo_ids[] = $attachment_id;
			}
			
		}
        ?>

        <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
        
            <header class="entry-header">
            
                <h1 class="entry-title"><?php the_title(); ?></h1>
                
                <h4 class="doublef-gallery-photos-num">
                <?php 
                $singular_photos = esc_attr__( 'photo', 'doublef-galleries' );
                $plural_photos = esc_attr__( 'photos', 'doublef-galleries' );
                $photos_string = ( $photos_in_gallery == 1 ) ? $singular_photos : $plural_photos;
                printf( '%d ' . $photos_string, $photos_in_gallery ); 
                ?>
                </h4>
                
            </header><!-- .entry-header -->
        
            <div class="entry-content">
            
				<?php 
                // content
                if( 'above' == $content_pos ) the_content();
                
                // columns number
                $gallery_col_num = get_post_meta( get_the_ID(), DOUBLEF_GALLERIES_PREFIX . 'gal_cols_num', TRUE );
                
                // caption
                $gallery_caption = get_post_meta( get_the_ID(), DOUBLEF_GALLERIES_PREFIX . 'gal_show_photo_descr', TRUE );
                // query args
                $q_args = array(
                    'post_type' => 'attachment', 
                    'post_status' => 'any', 
                    'posts_per_page' => -1, 
					'orderby' => 'post__in', 
                );
                // append to query if condition met
				if( ! empty( $gallery_repository ) ) $q_args[ 'post__in' ] = $gallery_photo_ids;
                // run query
                $qry = new WP_Query( $q_args );
                
                if( ! $qry->have_posts() ) {
                    ?>
                    
                    <p>
                    
                    <?php esc_attr_e( 'Unfortunately no photos were found attached to this gallery post!', 'doublef-galleries' ); ?>
                    
                    </p>
                    
                    <?php
                } else {
                    
                    ?>
                    
                    <div class="grid doublef-gallery-wrap">
                    
                    <?php
                    while( $qry->have_posts() ) : $qry->the_post();
                        
                        $photo_url = wp_get_attachment_url( get_the_ID() );
                        $photo_img = wp_get_attachment_image( get_the_ID(), 'full' );
                        ?>
                        
                        <div class="doublef-gallery-item grid__col grid__col--<?php echo intval( $gallery_col_num ); ?>-of-12 grid__col--m-2-of-4">
                        
                            <figure class="post-thumbnail">
                            
                                <a href="<?php echo $photo_url; ?>" title="<?php the_title(); ?>"><?php echo $photo_img; ?></a>
                                
                            </figure>
                            
                            <?php if( '' != get_the_excerpt() && 'yes' == $gallery_caption ) : ?>
                            
                                <div class="wp-caption"><div class="wp-caption-text"><?php the_excerpt(); ?></div></div>
                                
                            <?php endif; ?>
                            
                        </div>
                        
                        <?php
                        
                    endwhile;
					
					wp_reset_postdata();
                    
                    ?>
                    
                    </div><!-- .grid -->
                    <?php
                    
                }
				
				if( 'below' == $content_pos ) the_content();
				
                ?>
                
            </div><!-- .entry-content -->
            
        </article><!-- #post-## -->
        
		<?php
        $show_prev_next = ( '' != get_theme_mod( 'doublef-galleries-show-prev-next-nav', 'no' ) ) ? esc_attr__( get_theme_mod( 'doublef-galleries-show-prev-next-nav', 'no' ) ) : 'yes';
        if( 'yes' == $show_prev_next ) {
            
            the_post_navigation( array(
                'next_text' => '<span class="meta-nav" aria-hidden="true">' . esc_attr__( 'Next:', 'doublef-galleries' ) . '</span> ' .
                    '<span class="screen-reader-text">' . esc_attr__( 'Next event:', 'doublef-galleries' ) . '</span> ' .
                    '<span class="post-title">%title</span>',
                'prev_text' => '<span class="meta-nav" aria-hidden="true">' . esc_attr__( 'Previous:', 'doublef-galleries' ) . '</span> ' .
                    '<span class="screen-reader-text">' . esc_attr__( 'Previous event:', 'doublef-galleries' ) . '</span> ' .
                    '<span class="post-title">%title</span>',
            ) );
            
        } else {

			// next gallery link
			$next_post = get_adjacent_post( false, '', true, Doublef_Galleries::$ct_slug );
			$next_post_title = '';
			if( isset( $next_post->ID ) ) {
				$next_id = $next_post->ID;
				$next_post_title = $next_post->post_title;
			} else { 
				$args = array( 'posts_per_page' => '1', 'post_type' => Doublef_Galleries::$cpt_slug );
				$next_post = new WP_Query( $args );
				$next_id = $next_post->post->ID;
				$next_post_title = $next_post->post->post_title;
			}
			
			// handle next gallery link
			if( $next_id != get_the_ID() ) { 
				$next_photos_num = 0;
				$next_photos_repository = get_post_meta( $next_id, DOUBLEF_GALLERIES_PREFIX . 'gal_photos', TRUE );
				if( ! empty( $next_photos_repository ) ) $next_photos_num = count( $next_photos_repository );
			?>
			
			<div class="doublef-gallery-next-wrap">
            
				<a href="<?php echo esc_url( get_permalink( $next_id ) ); ?>" title="<?php echo esc_attr( $next_post_title ); ?>" class="next-gallery-link">
                
					<div class="doublef-gallery-next-text">
						<span class="like-title doublef-gallery-next-pre-title"><?php esc_attr_e( 'Next:', 'doublef-galleries' ); ?></span>
						<span class="like-title doublef-gallery-next-title"><?php echo esc_attr( $next_post_title ); ?></span>
						<span class="like-title doublef-gallery-next-photos-num"><?php printf( '%d ' . $photos_string, $next_photos_num ); ?></span>
					</div>
					<?php if( has_post_thumbnail( $next_id ) ) { ?>
						<div class="doublef-gallery-next-thumb">
							<?php echo get_the_post_thumbnail( $next_id, 'thumbnail' ); ?>
						</div>
                        <div class="gallery-bullet-next"><i class="fa fa-chevron-right"></i></div>
					<?php } ?>
                    
				</a>
                
			</div>
			
			<?php } // if only one post in all galleries 
			
		} // end 'yes' == $show_prev_next
		
        // If comments are open or we have at least one comment, load up the comment template.
        if ( 'no' == $disable_comments && ( comments_open() || get_comments_number() ) ) :
            comments_template();
        endif;

    endwhile; // End of the loop.
	
    ?>

    </main><!-- #main -->
    
</div><!-- #primary -->

<?php
if( 'yes' == $use_sidebar ) get_sidebar();

get_footer();